Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(246)

Unified Diff: ios/chrome/browser/payments/payment_request_util.h

Issue 2744823003: [Payment Request] Generic edit form (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/payments/payment_request_util.h
diff --git a/ios/chrome/browser/payments/payment_request_util.h b/ios/chrome/browser/payments/payment_request_util.h
index f247e9aafab5bed40aa46025c9626823153fc016..88c3be14ff098483fdc33d9e6f60de1e0616d340 100644
--- a/ios/chrome/browser/payments/payment_request_util.h
+++ b/ios/chrome/browser/payments/payment_request_util.h
@@ -23,23 +23,28 @@ class PaymentRequest;
namespace payment_request_util {
-// Helper function to get the name label from an autofill profile. Returns nil
-// if the name field is empty.
+// Helper function to create a name label from an autofill profile. Returns nil
+// if the resulting label is empty.
NSString* GetNameLabelFromAutofillProfile(
const autofill::AutofillProfile& profile);
-// Helper function to get the address label from an autofill profile. Returns
-// nil if the address field is empty.
-NSString* GetAddressLabelFromAutofillProfile(
+// Helper function to create a shipping address label from an autofill profile.
+// Returns nil if the resulting label is empty.
+NSString* GetShippingAddressLabelFromAutofillProfile(
const autofill::AutofillProfile& profile);
-// Helper function to get the phone number label from an autofill profile.
-// Returns nil if the phone number field is empty.
+// Helper function to create a billing address label from an autofill profile.
+// Returns nil if the resulting label is empty.
+NSString* GetBillingAddressLabelFromAutofillProfile(
+ const autofill::AutofillProfile& profile);
+
+// Helper function to create a phone number label from an autofill profile.
+// Returns nil if the resulting label is empty.
NSString* GetPhoneNumberLabelFromAutofillProfile(
const autofill::AutofillProfile& profile);
-// Helper function to get the email label from an autofill profile. Returns nil
-// if the email field is empty.
+// Helper function to create an email label from an autofill profile. Returns
+// nil if the resulting label is empty.
NSString* GetEmailLabelFromAutofillProfile(
const autofill::AutofillProfile& profile);

Powered by Google App Engine
This is Rietveld 408576698